@@ -4,7 +4,7 @@ package JavaScript::Const::Exporter;
 
 use v5.10;
 
-use Moo;
+use Moo 1.002000;
 use MooX::Options
     protect_argv => 0,
     usage_string => '%c %o [output-filename]';
@@ -14,7 +14,7 @@ use JSON::MaybeXS ();
 use Module::Load qw/ load /;
 use Package::Stash;
 use Ref::Util qw/ is_scalarref /;
-use Sub::Identify qw/ is_sub_constant /;
+use Sub::Identify 0.06 qw/ is_sub_constant /;
 use Try::Tiny;
 use Types::Common::String qw/ NonEmptySimpleStr /;
 use Types::Standard qw/ ArrayRef Bool HashRef InstanceOf /;
@@ -26,7 +26,7 @@ use Types::Standard qw/ ArrayRef Bool HashRef InstanceOf /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.2';
+our $VERSION = 'v0.1.3';
 
 
 option use_var => (
@@ -208,7 +208,7 @@ JavaScript::Const::Exporter - Convert exported Perl constants to JavaScript
 
 =head1 VERSION
 
-version v0.1.2
+version v0.1.3
 
 =head1 SYNOPSIS
 
